@@ -1,9 +1,9 @@
-Rtweets <- function(session=getCurlHandle(), num=25) {
-    searchTwitter("#rstats", session, num)
+Rtweets <- function(session=getCurlHandle(), num=25, ...) {
+    searchTwitter("#rstats", session, num, ...)
 }
 
 searchTwitter <- function(searchString, session=getCurlHandle(),
-                          num=25) {
+                          num=25, ...) {
     ## A basic search function.  Only implements a search on a string
     ## and will return num results
 
@@ -12,7 +12,7 @@ searchTwitter <- function(searchString, session=getCurlHandle(),
         stop("searchString is limited to 140 characters")
     url <- paste("http://search.twitter.com/search.json?q=",
                  qrySearch, "&rpp=", num, sep="")
-    out <- getURL(url)
+    out <- getURL(url, ...)
     jsonList <- twFromJSON(out)[[1]]
     sapply(jsonList, buildStatus)
 }
