@@ -1,19 +1,19 @@
-publicTimeline <- function(session=getCurlHandle()) {
+publicTimeline <- function(session=getCurlHandle(), ...) {
     out <- getURL("http://twitter.com/statuses/public_timeline.json",
-                  curl=session)
+                  curl=session, ...)
     jsonList <- twFromJSON(out)
     sapply(jsonList, buildStatus)
 }
 
-friendsTimeline <- function(session=getCurlHandle()) {
+friendsTimeline <- function(session=getCurlHandle(), ...) {
     ## FIXME: Does not currently support parameters
     out <- getURL("http://twitter.com/statuses/friends_timeline.json",
-                  curl=session)
+                  curl=session, ...)
     jsonList <- twFromJSON(out)
     sapply(jsonList, buildStatus)
 }
 
-userTimeline <- function(user, session=getCurlHandle()) {
+userTimeline <- function(user, session=getCurlHandle(), ...) {
     if (inherits(user, "user"))
         user <- user@screenName
 
@@ -24,15 +24,15 @@ userTimeline <- function(user, session=getCurlHandle()) {
 
     url <- paste("http://twitter.com/statuses/user_timeline.json?screen_name=",
                  URLencode(user), sep="")
-    out <- getURL(url, curl=session)
+    out <- getURL(url, curl=session, ...)
     jsonList <- twFromJSON(out)
     sapply(jsonList, buildStatus)
 }
 
-mentions <- function(session=getCurlHandle()) {
+mentions <- function(session=getCurlHandle(), ...) {
     ## FIXME: Does not support any parameters
     out <- getURL("http://twitter.com/statuses/mentions.json",
-                  curl=session)
+                  curl=session, ...)
     jsonList <- twFromJSON(out)
     sapply(jsonList, buildStatus)
 }
